
/**
 * GLCD Hardware layer
 */

#include <LPC23xx.H>
#include "glcdhw.h"


/**
 * Hardware connection: 
 *
 *  P0.9 - MOSI 1
 *  P0.7 - SCK1
 *  P0.6 - LCD_CS
 *  P0.5 - Backlight									   
 *  P0.4 - LCD_RS
 */

void hal_LCD_CS(int state)
{
	if (state == 0) IOCLR0 = 1<<6; else IOSET0 = 1<<6;
}

void hal_LCD_backlight(int state)
{
	if (state == 0) IOCLR0 = 1<<5; else IOSET0 = 1<<5;
}
													 
void hal_LCD_RS(int state)
{
	if (state == 0) IOCLR0 = 1<<4; else IOSET0 = 1<<4;
}
													 
void hal_LCD_init(void)
{

	// MOSI1
	PINSEL0 |= (unsigned int)1<<19;
	PINSEL0 &= ~(unsigned int)1<<18;

	// MISO1
	PINSEL0 |= (unsigned int)1<<17;
	PINSEL0 &= ~(unsigned int)1<<16;

	// SCK1
	PINSEL0 |= (unsigned int)1<<15;
	PINSEL0 &= ~(unsigned int)1<<14;

	// CS
	PINSEL0 &= ~(unsigned int)1<<13;
	PINSEL0 &= ~(unsigned int)1<<12;
	IODIR0 |= (unsigned int)1<<6;

	// BACKPLANE
	PINSEL0 &= ~(unsigned int)1<<11;
	PINSEL0 &= ~(unsigned int)1<<10;
	IODIR0 |= (unsigned int)1<<5;

	// RS
	PINSEL0 &= ~(unsigned int)1<<9;
	PINSEL0 &= ~(unsigned int)1<<8;
	IODIR0 |= (unsigned int)1<<4;

			/*
		SSP1 Setup
			SPH = 1
			SPO = 1
			Mode = SPI
			DSS = 8
			Clock prescaler = 0x00E0 (1MHz)
			==== MM ====
			ADS8341 SPI port:
						
			SCR = PCLK / (CPSDVSR  [SCR+1]) = PCLK / ( 224 * [ 14 + 1]) = 0
			CPSDVSR -- see below
			CPOL = 0 -- clock polarity low between frames
			CPHA = 0 -- data sampled on the first edge --rising edge
			FRF = 00 -- SPI mode
			DSS =  7 -- 8 bit data transfer
		*/
		
		SSP1CR0 = 	(unsigned int)(1 << 2)|
					(unsigned int)(1 << 1)|
					(unsigned int)(1 << 0); //0x00C7;
		/*
			SOD = 0 -- slave output disable - irrelevant since in master mode
			MS = 0	-- device is master
			SSE = 1	-- ssp1 on
			LBM = 0 -- no loop back mode
		*/			
		SSP1CR1 = 	(unsigned int)(1 << 1); //0x0002; //enable master mode
		
		SSP1CPSR = 0x000A;	// 1.8MHz
		SSP1CPSR = 0x0010;	// 1.125MHz
		SSP1IMSC= 0x0000;	


}


/**
 * Transfer byte via SSP1 
 *
 * Function transfers single byte via SSP1 
   and return byte read within same transfer.
 *
 * @param 
 *   dat byte sent from master to slave
 * @return 
 *   byte sent from slave to master
 */
unsigned char  hal_LCD_transfer(unsigned char dat) {
  SSP1DR  = dat;                	// send data
  while ((SSP1SR & 0x10)) ;     	// wait for transfer completed
return SSP1DR;
}






